summaryrefslogtreecommitdiff
path: root/drivers/staging/greybus/greybus_id.h
diff options
context:
space:
mode:
authorViresh Kumar <viresh.kumar@linaro.org>2015-04-01 20:32:04 +0530
committerGreg Kroah-Hartman <gregkh@google.com>2015-04-06 12:07:30 +0200
commit9f5f30e712430912f4cff65e97dd36f9b3bdbe4e (patch)
treed7897f0cff367818aa75602ea615b9674375a1d5 /drivers/staging/greybus/greybus_id.h
parent8e2e22d7830616ac37a9045e9e749e35cbc10ffe (diff)
greybus: driver corresponds to a bundle, not interface
A Greybus driver will bind to a bundle, not an interface. Lets follow this rule in code. Signed-off-by: Viresh Kumar <viresh.kumar@linaro.org> Signed-off-by: Greg Kroah-Hartman <gregkh@google.com>
Diffstat (limited to 'drivers/staging/greybus/greybus_id.h')
-rw-r--r--drivers/staging/greybus/greybus_id.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/drivers/staging/greybus/greybus_id.h b/drivers/staging/greybus/greybus_id.h
index 3c462ef7ba6c..4204a8c7ca74 100644
--- a/drivers/staging/greybus/greybus_id.h
+++ b/drivers/staging/greybus/greybus_id.h
@@ -9,18 +9,20 @@
#include <linux/mod_devicetable.h>
-struct greybus_interface_id {
+struct greybus_bundle_id {
__u16 match_flags;
__u16 vendor;
__u16 product;
+ __u8 class_type;
__u64 unique_id;
kernel_ulong_t driver_info __aligned(sizeof(kernel_ulong_t));
};
/* Used to match the greybus_interface_id */
#define GREYBUS_ID_MATCH_VENDOR BIT(0)
#define GREYBUS_ID_MATCH_PRODUCT BIT(1)
#define GREYBUS_ID_MATCH_SERIAL BIT(2)
+#define GREYBUS_ID_MATCH_CLASS_TYPE BIT(3)
#endif /* __LINUX_GREYBUS_ID_H */
@@ -9,18 +9,20 @@
kernel_ulong_t driver_info __aligned(sizeof(kernel_ulong_t));
};
-/* Used to match the greybus_interface_id */
+/* Used to match the greybus_bundle_id */
#define GREYBUS_ID_MATCH_VENDOR BIT(0)
#define GREYBUS_ID_MATCH_PRODUCT BIT(1)